From 0de6e616e0d0890dc8e7f89dc263c82a18ad2b3d Mon Sep 17 00:00:00 2001
From: Zooko O'Whielacronx <zooko@zooko.com>
Date: Thu, 20 Nov 2008 14:15:45 -0700
Subject: [PATCH] setup: use "setup.py develop --multi-version" so that if
 there is a too-old version of a dependency installed this doesn't prevent
 Tahoe's "develop" and run-in-place from working

---
 setup.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/setup.py b/setup.py
index 9f290f27..2aae4789 100644
--- a/setup.py
+++ b/setup.py
@@ -31,7 +31,7 @@ def add_tahoe_paths():
 
       mkdir -p $(BASEDIR)/support/lib/python2.5/site-packages
        (or cygpath equivalent)
-      setup.py develop --prefix=$(BASEDIR)/support
+      setup.py develop --multi-version --prefix=$(BASEDIR)/support
 
     This installs .eggs for any dependent libraries that aren't already
     available on the system, into support/lib/pythonN.N/site-packages (or
@@ -291,7 +291,7 @@ class BuildTahoe(Command):
                                stat.S_IXOTH | stat.S_IROTH )
         os.chmod(bin_tahoe, new_mode)
 
         # 'setup.py develop --prefix SUPPORT' will complain if SUPPORTLIB is
         # not on PYTHONPATH, because it thinks you are installing to a place
         # that will not be searched at runtime (which is true, except that we
         # add SUPPORTLIB to PYTHONPATH to run tests, etc). So set up
@@ -300,7 +300,7 @@ class BuildTahoe(Command):
         if not os.path.isdir(supportlib):
             os.makedirs(supportlib)
 
-        command = [sys.executable, "setup.py", "develop", "--prefix", "support"]
+        command = [sys.executable, "setup.py", "develop", "--multi-version", "--prefix", "support"]
         if sys.platform == "linux2":
             # workaround for tahoe #229 / setuptools #17, on debian
             command.extend(["--site-dirs", "/var/lib/python-support/" + pyver])
@@ -291,7 +291,7 @@ class BuildTahoe(Command):
         os.chmod(bin_tahoe, new_mode)
 
-        # 'setup.py develop --prefix SUPPORT' will complain if SUPPORTLIB is
+        # 'setup.py develop --multi-version --prefix SUPPORT' will complain if SUPPORTLIB is
         # not on PYTHONPATH, because it thinks you are installing to a place
         # that will not be searched at runtime (which is true, except that we
-- 
2.45.2